@@ -261,7 +261,11 @@ class Curve:
         for k, v in self.dependents.items():
             out[k] = v(setpoint, units)
         if full and self.subcurve:
-            out.update(self.subcurve(self.source_setpoints(setpoint, units), self.source_setpoints.units,  full))
+            out.update(
+                self.subcurve(
+                    self.source_setpoints(setpoint, units), self.source_setpoints.units, full
+                )
+            )
         return out
 
     def get_source_setpoint(self, setpoint, units="same"):
@@ -332,7 +336,10 @@ class Curve:
         if self.subcurve:
             new_source_setpoints = self.source_setpoints(new_setpoints)
             self.source_setpoints = Dependent(
-                new_source_setpoints, self.source_setpoints.name, self.source_setpoints.units, index=self.source_setpoints.index
+                new_source_setpoints,
+                self.source_setpoints.name,
+                self.source_setpoints.units,
+                index=self.source_setpoints.index,
             )
         # finish
         self.setpoints = Setpoints(new_setpoints, self.setpoints.name, self.setpoints.units)
@@ -340,7 +347,7 @@ class Curve:
         for obj in self.dependents.values():
             setattr(self, obj.name, obj)
         self.interpolate()
-    
+
     def sort(self):
         order = self.setpoints[:].argsort()
         self.setpoints[:] = self.setpoints[order]
@@ -352,7 +359,6 @@ class Curve:
             d[:] = d[order]
         self.interpolate()
 
-
     def offset_by(self, dependent, amount):
         """Offset a dependent by some ammount.
 
@@ -369,7 +375,7 @@ class Curve:
         """
         # offset
         self.dependents[dependent].positions += amount
-        self.dependents[dependent].interpolate()
+        self.interpolate()
 
     def offset_to(self, dependent, destination, setpoint, setpoint_units="same"):
         """Offset a dependent such that it evaluates to `destination` at `setpoint`.
@@ -474,6 +480,17 @@ class Curve:
             plt.savefig(image_path, transparent=True, dpi=300)
             plt.close(fig)
 
+    def rename_dependent(self, old_name, new_name):
+        try:
+            dep = self.dependents[old_name]
+        except KeyError:
+            raise ValueError(f"Dependent '{old_name}' not found")
+        dep.name = new_name
+        delattr(self, old_name)
+        setattr(self, new_name, dep)
+        self.dependents = {k if k != old_name else new_name: v for k, v in self.dependents.items()}
+        self.interpolate()
+
     @classmethod
     def read(cls, filepath, subcurve=None):
         filepath = pathlib.Path(filepath)
@@ -555,8 +572,8 @@ class Curve:
         with open(out_path, "at") as f:
             np.savetxt(f, out_arr.T, fmt=self.fmt, delimiter="\t")
         # save subcurve
-        if self.subcurve:
-            self.subcurve.save(save_directory=save_directory)
+        if full and self.subcurve:
+            self.subcurve.save(save_directory=save_directory, full=True, verbose=verbose)
         # plot
         if plot:
             image_path = out_path.with_suffix(".png")
